summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorBen Pfaff <blp@ovn.org>2020-06-17 14:16:08 -0700
committerBen Pfaff <blp@ovn.org>2020-10-21 11:28:24 -0700
commit91fc374a9c5a2a4d9520aaa3588a7a18338a476e (patch)
tree36e097d0f7b655e90179c04e21eb7fe4c400889b /include
parentf51cf36d86e4a51630dc2781034149c13a634d67 (diff)
downloadopenvswitch-91fc374a9c5a2a4d9520aaa3588a7a18338a476e.tar.gz
Eliminate use of term "slave" in bond, LACP, and bundle contexts.
The new term is "member". Most of these changes should not change user-visible behavior. One place where they do is in "ovs-ofctl dump-flows", which will now output "members:..." inside "bundle" actions instead of "slaves:...". I don't expect this to cause real problems in most systems. The old syntax is still supported on input for backward compatibility. Signed-off-by: Ben Pfaff <blp@ovn.org> Acked-by: Alin Gabriel Serdean <aserdean@cloudbasesolutions.com>
Diffstat (limited to 'include')
-rw-r--r--include/openvswitch/ofp-actions.h28
1 files changed, 15 insertions, 13 deletions
diff --git a/include/openvswitch/ofp-actions.h b/include/openvswitch/ofp-actions.h
index 226e86d0b..41bcb55d2 100644
--- a/include/openvswitch/ofp-actions.h
+++ b/include/openvswitch/ofp-actions.h
@@ -66,7 +66,7 @@ struct vl_mff_map;
OFPACT(CONTROLLER, ofpact_controller, userdata, "controller") \
OFPACT(ENQUEUE, ofpact_enqueue, ofpact, "enqueue") \
OFPACT(OUTPUT_REG, ofpact_output_reg, ofpact, "output_reg") \
- OFPACT(BUNDLE, ofpact_bundle, slaves, "bundle") \
+ OFPACT(BUNDLE, ofpact_bundle, members, "bundle") \
\
/* Header changes. */ \
OFPACT(SET_FIELD, ofpact_set_field, ofpact, "set_field") \
@@ -364,24 +364,24 @@ struct ofpact_output_trunc {
);
};
-/* Bundle slave choice algorithm to apply.
+/* Bundle member choice algorithm to apply.
*
* In the descriptions below, 'slaves' is the list of possible slaves in the
* order they appear in the OpenFlow action. */
enum nx_bd_algorithm {
- /* Chooses the first live slave listed in the bundle.
+ /* Chooses the first live member listed in the bundle.
*
- * O(n_slaves) performance. */
+ * O(n_members) performance. */
NX_BD_ALG_ACTIVE_BACKUP = 0,
/* Highest Random Weight.
*
- * for i in [0,n_slaves):
+ * for i in [0,n_members):
* weights[i] = hash(flow, i)
- * slave = { slaves[i] such that weights[i] >= weights[j] for all j != i }
+ * member = { members[i] such that weights[i] >= weights[j] for all j != i }
*
* Redistributes 1/n_slaves of traffic when a slave's liveness changes.
* O(n_slaves) performance.
*
* Uses the 'fields' and 'basis' parameters. */
NX_BD_ALG_HRW = 1
@@ -394,7 +394,7 @@ struct ofpact_bundle {
OFPACT_PADDED_MEMBERS(
struct ofpact ofpact;
- /* Slave choice algorithm to apply to hash value. */
+ /* Member choice algorithm to apply to hash value. */
enum nx_bd_algorithm algorithm;
/* What fields to hash and how. */
@@ -403,10 +403,12 @@ struct ofpact_bundle {
struct mf_subfield dst;
- /* Slaves for output. */
- unsigned int n_slaves;
+ bool compat_syntax;
+
+ /* Members for output. */
+ unsigned int n_members;
);
- ofp_port_t slaves[];
+ ofp_port_t members[];
};
/* OFPACT_SET_VLAN_VID.
@@ -364,24 +364,24 @@ struct ofpact_output_trunc {
*
- * In the descriptions below, 'slaves' is the list of possible slaves in the
+ * In the descriptions below, 'members' is the list of possible members in the
* order they appear in the OpenFlow action. */
enum nx_bd_algorithm {
@@ -364,24 +364,24 @@ struct ofpact_output_trunc {
*
- * Redistributes 1/n_slaves of traffic when a slave's liveness changes.
- * O(n_slaves) performance.
+ * Redistributes 1/n_members of traffic when a member's liveness changes.
+ * O(n_members) performance.
*
* Uses the 'fields' and 'basis' parameters. */